require 'dalli'

module CertificateHelpers
  # get Authorized User info.  This implementation may change
  # so that the authorized user information is more easily accessible
  # among a broad range of applications, but for now this is what works.
  def user(env)
    ConsoleAuth.get_user(env)
  end

  # this is intentially not named successful? so as to not overwrite the
  # existing Rack method successful?
  def is_successful? status
    status.to_i < 300 && status.to_i >= 200
  end

  def memcache_client
    @memcache_client ||= Dalli::Client.new('127.0.0.1:11211', :compression => true,
                                                              :namespace => 'certmgr',
                                                              :expires_in => cache_expiration)
  end

  def purge_memcache_keys
    memcache_client.multi do
      nodes = memcache_client.get node_array_key
      if nodes
        all_node_data = memcache_client.get_multi nodes
        nodes = nodes.delete_if { |n| all_node_data[n].nil? }
        memcache_client.set node_array_key, nodes
        all_node_data.delete_if { |key, value| value == nil }
      end
    end
  end

  def get_all_cached_nodes
    purge_memcache_keys || {}
  end

  def add_to_cache node, data
    memcache_client.multi do
      add_node_to_array node
      memcache_client.set node, data
    end
  end

  def purge_from_cache node
    memcache_client.delete node
  end

  def add_node_to_array node
    nodes = memcache_client.get node_array_key
    nodes ||= []
    nodes << node
    memcache_client.set node_array_key, nodes
  end

  def node_array_key
    :actioned_node_list
  end

  def cache_expiration
    # 1 day in seconds
    60 * 60 * 24
  end
end
