require File.join(File.dirname(__FILE__), 'certapi')

module FakeCSRHelpers

  def self.included(base)
    path = '/opt/puppet/share/puppet-dashboard/certs'
    CertAPI.config({
      :ca_file_path   => File.join(path, 'pe-internal-dashboard.ca_cert.pem'),
      :cert_path      => File.join(path, 'pe-internal-dashboard.cert.pem'),
      :cert_key_path  => File.join(path, 'pe-internal-dashboard.private_key.pem'),
    })
  end

  def clear_csrs(options = {})

    if options[:clear]
      clear_names = options[:clear].to_a
    else

      names = CertAPI.certnames

      keep =  [
        'agent1',
        'master',
        'pe-internal-broker',
        'pe-internal-dashboard',
        'pe-internal-mcollective-servers',
        'pe-internal-peadmin-mcollective-client',
        'pe-internal-puppet-console-mcollective-client',
      ]

      keep.concat(options[:except]) if options[:except]

      clear_names = names - keep
    end

    clear_names.each do |cn|
      ret = CertAPI.remove(cn)
      raise 'Error removing certificate via the API' unless ret.code == "200"
    end
  end

  def openssl_command(options = {})
    cn = options[:cn]
    alt = options[:alt]
    master = options[:master]
    pem_path = "/etc/puppetlabs/puppet/ssl/private_keys/#{master}.pem"
    if alt
      command = <<COMMAND
 SAN='DNS:#{alt}' openssl req -config /tmp/openssl_altnames.cnf \
 -new -key #{pem_path} \
 -subj '/CN=#{cn}' -out /tmp/request.csr
COMMAND
    else
      command = <<COMMAND
openssl req -new -key #{pem_path} \
-subj '/CN=#{cn}' -out /tmp/request.csr
COMMAND
    end
  end

  def put_command(cn, base_url = 'https://33.33.33.10:8140/production/certificate_request')
    command = <<COMMAND
curl -k -X PUT -H 'Content-Type: text/plain' --data-binary \
@/tmp/request.csr #{base_url}/#{cn}
COMMAND
  end

end
