define(['dom', '../../../views/app', '../../../collections/requests', '../../../models/request', 'core_models/user'],
  function($, AppView, RequestsCollection, RequestModel, UserModel) {

  describe('Application view', function() {

    it('fetches CSRs when created', function() {

      var collection = sinon.stub(new RequestsCollection);

      collection.fetch.returns($.Deferred().promise());

      new AppView({
        requests: collection,
        skip_stylesheet: true
      });

      expect(collection.fetch).toHaveBeenCalledOnce();
    });

    it('listens to a "reset" event from the CSR collection', function() {
      var stub = sinon.stub(AppView.prototype, 'show_list'),
          collection = new RequestsCollection,
          server = sinon.fakeServer.create();

      var app = new AppView({
        requests: collection,
        skip_stylesheet: true
      }).render();

      collection.trigger('reset');

      expect(stub).toHaveBeenCalledOnce();

      server.restore();
      stub.restore();
    });

    describe('rendering', function() {

      var view,
          server,
          collection;

      beforeEach(function() {

        collection = new RequestsCollection;

        server = sinon.fakeServer.create();

        view = new AppView({
          requests: collection,
          skip_stylesheet: true
        });

        view.core.user = new UserModel({
          role: 'admin'
        });

      });

      afterEach(function() {
        server.restore();

        view.core.user = {};
      });

      it('should show a loading message while fetching the collection', function() {
        view.render();

        expect(view.ui.loading_message.css('display')).not.toBe('none');
      });

      describe('the certificates list', function() {

        beforeEach(function() {
          view.render();
        });

        it('should no longer show a loading message', function() {
          view.show_list();

          expect(view.ui.loading_message.css('display')).toBe('none')
        });

        it('should show a bunch of help text if there are no CSRs outstanding', function() {
          view.show_list();

          expect(view.ui.no_requests_container[0].innerHTML).toBeTruthy();
          expect(view.ui.requests_container[0].innerHTML).toBeFalsy();
        });

        it('should show the RequestsView if there are CSRs', function() {

          collection.add(new RequestModel);

          view.show_list();

          expect(view.ui.no_requests_container[0].innerHTML).toBeFalsy();
          expect(view.ui.requests_container[0].innerHTML).toBeTruthy();
        });

        it('should show an error if the collection load fails', function() {

          server.respondWith([500, {}, 'Error']);

          server.respond();

          expect(view.ui.loading_message[0].innerHTML).toMatch('error occured');

        });
      });

    });

  });

});