#!/opt/puppet/bin/ruby
require 'rubygems'
require 'rack'
require 'sinatra/base'
require 'yaml'
require 'logger'
require 'json'
#require 'sequel' # DB driver

## Include all classes in the models directory:
Dir.glob("#{File.dirname(__FILE__)}/models/*.rb", &method(:require))
## Include all classes in the classes directory:
Dir.glob("#{File.dirname(__FILE__)}/classes/*.rb", &method(:require))

# Include ConsoleAuth
require "#{File.dirname(__FILE__)}/../console-auth/lib/console_auth"

# Configure ConsoleAuth

if ::ConsoleAuth.active?
  Gem.use_paths nil, ["#{File.dirname(__FILE__)}/../console-auth/vendor/rubygems"]

  require "#{File.dirname(__FILE__)}/../console-auth/lib/cas_client"
  require "#{File.dirname(__FILE__)}/../console-auth/lib/rack_authorization"

  ::ConsoleAuth.init

  use Rack::Session::Cookie,
    :key => ::ConsoleAuth.get_config['authentication']['session_key'],
    :secret => ::ConsoleAuth.get_config['authentication']['session_secret']

  use Rack::Cas::Client,
    :cas_base_url => ::ConsoleAuth.cas_base_url,
    :session_dir => './tmp/sessions',
    :logger => Logger.new('/var/log/pe-console-auth/cas_client.log'),
    :cas_port => ::ConsoleAuth.get_config['authentication']['cas_port'],
    :allow_unauthenticated_urls => ::ConsoleAuth.unauthenticated_restrictions

  use Rack::ConsoleAuth::Authorization
end

### Set up basic rack functionality:
use Rack::CommonLogger

use Rack::Static,
	:urls	=> ['/css', '/img', '/js', '/favicon.ico'],
	:root	=> 'public'

use Rack::Reloader


### Begin loading core

## This needs to be moved into a core class that encapsulates the configuration
## (not to mention the pesky globals I've hacked in a hurry)
config = YAML::load(IO.read("#{File.dirname(__FILE__)}/config/config.yml"))

$path = File.dirname(__FILE__)
$baseURL = config['baseURL']


### Begin loading applications

## Assemble hash for URLMap of applications' public directories:
application_public_dir_map = {}
Console::Models::Applications.public_directories do |name, dir|
  application_public_dir = '/' + name
  application_public_dir_map.store(application_public_dir, Rack::File.new(dir))
end

## Assemble hash for URLMap of all provided services from applications:
application_service_map = {}
Console::Models::Applications.load_services do |name|
  application_service = '/' + name
  application_service_map.store(application_service, Object.const_get(name.capitalize).const_get('Main'))
end


### Assemble main routes:
# This should probably be assembled in a more dynamic way, but for now it works.
url_map = {
  '/'             => Console::Main,
  '/config'       => Console::Config,
  '/user'         => Console::User,
  '/applications' => Rack::URLMap.new(application_public_dir_map),
  '/services'     => Rack::URLMap.new(application_service_map)
}

routes = Rack::URLMap.new(url_map)

## Off we go!
run routes
