require 'emcee/cache_base'
require 'emcee/cache'

class Emcee
  class FileCache < Emcee::CacheBase
    def cache_path
      File.join("/tmp", digest)
    end

    def save(value)
      log("filecache saving [#{key.inspect}] [#{digest}] -> [#{value.inspect[0..255]}] [#{value.inspect.size}]")
      File.open(cache_path, 'w') {|f| f.puts(YAML.dump(value)) }
      value
    end

    def load
      value = YAML.load(File.read(cache_path))
      log("filecache retrieving [#{key.inspect}] [#{digest}] => [#{value.inspect[0..255]}] [#{value.inspect.size}]")
      value
    end

    def expire!
      File.delete(cache_path) if File.exists?(cache_path)
    end

    def cached?
      File.exists?(cache_path) and fresh?
    end

    def fresh?
      (Time.now - File.mtime(cache_path)) < 10 * 60 # 10 minute cache expiration
    end
  end
end
